summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorMichael Brown2009-07-07 19:09:21 +0200
committerMichael Brown2009-07-18 00:06:34 +0200
commit8a852280eb84ff6a43f8c08aeb52c3e21a5da31b (patch)
tree54b116ac0980f2fb999f2c4e8d7768eadef3c554 /src/include
parent[ipoib] Remove the queue set abstraction (diff)
downloadipxe-8a852280eb84ff6a43f8c08aeb52c3e21a5da31b.tar.gz
ipxe-8a852280eb84ff6a43f8c08aeb52c3e21a5da31b.tar.xz
ipxe-8a852280eb84ff6a43f8c08aeb52c3e21a5da31b.zip
[infiniband] Pass GMA as a parameter to GMA MAD handlers
Diffstat (limited to 'src/include')
-rw-r--r--src/include/gpxe/ib_gma.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/src/include/gpxe/ib_gma.h b/src/include/gpxe/ib_gma.h
index c921e251..04955e5c 100644
--- a/src/include/gpxe/ib_gma.h
+++ b/src/include/gpxe/ib_gma.h
@@ -17,9 +17,10 @@ struct ib_device;
struct ib_completion_queue;
struct ib_queue_pair;
union ib_mad;
+struct ib_gma;
-/** A MAD attribute handler */
-struct ib_mad_handler {
+/** A GMA attribute handler */
+struct ib_gma_handler {
/** Management class */
uint8_t mgmt_class;
/** Class version */
@@ -32,7 +33,7 @@ struct ib_mad_handler {
uint16_t attr_id;
/** Handle attribute
*
- * @v ibdev Infiniband device
+ * @v gma General management agent
* @v mad MAD
* @ret rc Return status code
*
@@ -40,14 +41,14 @@ struct ib_mad_handler {
* handler returns with a non-zero value in the MAD's @c
* method field, it will be sent as a response.
*/
- int ( * handle ) ( struct ib_device *ibdev, union ib_mad *mad );
+ int ( * handle ) ( struct ib_gma *gma, union ib_mad *mad );
};
/** MAD attribute handlers */
#define IB_MAD_HANDLERS __table ( struct ib_mad_handler, "ib_mad_handlers" )
/** Declare a MAD attribute handler */
#define __ib_mad_handler __table_entry ( IB_MAD_HANDLERS, 01 )
/** An Infiniband General Management Agent */
struct ib_gma {
@@ -40,14 +41,14 @@ struct ib_mad_handler {
};
-/** MAD attribute handlers */
-#define IB_MAD_HANDLERS __table ( struct ib_mad_handler, "ib_mad_handlers" )
+/** GMA attribute handlers */
+#define IB_GMA_HANDLERS __table ( struct ib_gma_handler, "ib_gma_handlers" )
-/** Declare a MAD attribute handler */
-#define __ib_mad_handler __table_entry ( IB_MAD_HANDLERS, 01 )
+/** Declare a GMA attribute handler */
+#define __ib_gma_handler __table_entry ( IB_GMA_HANDLERS, 01 )
/** An Infiniband General Management Agent */
struct ib_gma {